@@ -608,7 +608,13 @@ class Executor(object):
                 archive = self._chef.prepare(archive)
 
         if package.files:
-            archive_hash = "sha256:" + FileDependency(package.name, archive).hash()
+            archive_hash = (
+                "sha256:"
+                + FileDependency(
+                    package.name,
+                    Path(archive.path) if isinstance(archive, Link) else archive,
+                ).hash()
+            )
             if archive_hash not in {f["hash"] for f in package.files}:
                 raise RuntimeError(
                     "Invalid hash for {} using archive {}".format(package, archive.name)
